[org 0x7c00]
[bits 16]
BOOT_DRIVE equ 0x900
BOOTLOADER_OFFSET equ 0x1000 ; Second stage of bootloader

    ;Reset registers
    mov cx, 0
    mov ds, cx
    mov es, cx
    mov ss, cx

    mov [BOOT_DRIVE], dl ; Remember that the BIOS sets us the boot drive in 'dl' on boot
    mov bp, 0x7c00
    mov sp, bp

    mov bx, STARTED_LOADING
    call print
    call print_nl
    call load_bootloader ; read the kernel (and the rest of the bootloader) from disk

    mov bx, STARTING_STAGE
    call print
    call print_nl
    jmp BOOTLOADER_OFFSET
    jmp $ ; Should never be called

%include "boot/disk.asm"
%include "boot/print.asm"
%include "boot/print_hex.asm"

load_bootloader:
    mov dh, [SEC_COUNT]
    ;call print_hex


    mov dh, [CURRENT_MEM_LOAD]
    ;call print_hex
    ;call print_nl
    call disk_load
    ;mov bx, SECTOR_LOADED
    ;call print
    ;call print_nl


    ;Increment CURRENT_MEM_LOAD
    mov cx, [CURRENT_MEM_LOAD]
    add cx, 0x200
    mov [CURRENT_MEM_LOAD], cx

    mov al, [SEC_COUNT]
    cmp al, 0x12 ; If al >= 0x12, we're done. The rest will be loaded by the second stage 18 = 0x12
    jge done_load

    ;Increment sector ID
    inc al
    mov [SEC_COUNT], al
    jmp load_bootloader

done_load:
    ret

SEC_COUNT db 0x02
CURRENT_MEM_LOAD dw 0x1000
; It is a good idea to store it in memory because 'dl' may get overwritten

STARTED_LOADING db "Loading SteveOS...", 0
SECTOR_LOADED db "Sector loaded.", 0
STARTING_STAGE db "Starting bootloader second stage...", 0
; padding
times 510 - ($-$$) db 0
dw 0xaa55
